==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ScopeRestrictionFluent<A extends ScopeRestrictionFluent<A>> extends BaseFluent<A>{
  public ScopeRestrictionFluent() {
  }
  public ScopeRestrictionFluent(ScopeRestriction instance) {
    instance = (instance != null ? instance : new ScopeRestriction());

    if (instance != null) {
      this.withClusterRole(instance.getClusterRole());
      this.withLiterals(instance.getLiterals());
      this.withClusterRole(instance.getClusterRole());
      this.withLiterals(instance.getLiterals());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ClusterRoleScopeRestrictionBuilder clusterRole;
  private List<String> literals = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public ClusterRoleScopeRestriction buildClusterRole() {
    return this.clusterRole!=null ?this.clusterRole.build():null;
  }
  public A withClusterRole(ClusterRoleScopeRestriction clusterRole) {
    _visitables.get("clusterRole").remove(this.clusterRole);
    if (clusterRole!=null){ this.clusterRole= new ClusterRoleScopeRestrictionBuilder(clusterRole); _visitables.get("clusterRole").add(this.clusterRole);} else { this.clusterRole = null; _visitables.get("clusterRole").remove(this.clusterRole); } return (A) this;
  }
  public boolean hasClusterRole() {
    return this.clusterRole != null;
  }
  public ClusterRoleNested<A> withNewClusterRole() {
    return new ClusterRoleNested(null);
  }
  public ClusterRoleNested<A> withNewClusterRoleLike(ClusterRoleScopeRestriction item) {
    return new ClusterRoleNested(item);
  }
  public ClusterRoleNested<A> editClusterRole() {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(null));
  }
  public ClusterRoleNested<A> editOrNewClusterRole() {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(new ClusterRoleScopeRestrictionBuilder().build()));
  }
  public ClusterRoleNested<A> editOrNewClusterRoleLike(ClusterRoleScopeRestriction item) {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(item));
  }
  public A addToLiterals(int index,String item) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    this.literals.add(index, item);
    return (A)this;
  }
  public A setToLiterals(int index,String item) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    this.literals.set(index, item); return (A)this;
  }
  public A addToLiterals(java.lang.String... items) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    for (String item : items) {this.literals.add(item);} return (A)this;
  }
  public A addAllToLiterals(Collection<String> items) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    for (String item : items) {this.literals.add(item);} return (A)this;
  }
  public A removeFromLiterals(java.lang.String... items) {
    if (this.literals == null) return (A)this;
    for (String item : items) { this.literals.remove(item);} return (A)this;
  }
  public A removeAllFromLiterals(Collection<String> items) {
    if (this.literals == null) return (A)this;
    for (String item : items) { this.literals.remove(item);} return (A)this;
  }
  public List<String> getLiterals() {
    return this.literals;
  }
  public String getLiteral(int index) {
    return this.literals.get(index);
  }
  public String getFirstLiteral() {
    return this.literals.get(0);
  }
  public String getLastLiteral() {
    return this.literals.get(literals.size() - 1);
  }
  public String getMatchingLiteral(Predicate<String> predicate) {
    for (String item: literals) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingLiteral(Predicate<String> predicate) {
    for (String item: literals) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withLiterals(List<String> literals) {
    if (literals != null) {this.literals = new ArrayList(); for (String item : literals){this.addToLiterals(item);}} else { this.literals = null;} return (A) this;
  }
  public A withLiterals(java.lang.String... literals) {
    if (this.literals != null) {this.literals.clear(); _visitables.remove("literals"); }
    if (literals != null) {for (String item :literals){ this.addToLiterals(item);}} return (A) this;
  }
  public boolean hasLiterals() {
    return literals != null && !literals.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ScopeRestrictionFluent that = (ScopeRestrictionFluent) o;
    if (!java.util.Objects.equals(clusterRole, that.clusterRole)) return false;

    if (!java.util.Objects.equals(literals, that.literals)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterRole,  literals,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterRole != null) { sb.append("clusterRole:"); sb.append(clusterRole + ","); }
    if (literals != null && !literals.isEmpty()) { sb.append("literals:"); sb.append(literals + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ClusterRoleNested<N> extends ClusterRoleScopeRestrictionFluent<ClusterRoleNested<N>> implements Nested<N>{
    ClusterRoleNested(ClusterRoleScopeRestriction item) {
      this.builder = new ClusterRoleScopeRestrictionBuilder(this, item);
    }
    ClusterRoleScopeRestrictionBuilder builder;
    public N and() {
      return (N) ScopeRestrictionFluent.this.withClusterRole(builder.build());
    }
    public N endClusterRole() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/ScopeRestrictionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ScopeRestrictionFluent<A extends ScopeRestrictionFluent<A>> extends BaseFluent<A>{
  public ScopeRestrictionFluent() {
  }
  
  public ScopeRestrictionFluent(ScopeRestriction instance) {
    this.copyInstance(instance);
  }
  private ClusterRoleScopeRestrictionBuilder clusterRole;
  private List<String> literals = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ScopeRestriction instance) {
    instance = (instance != null ? instance : new ScopeRestriction());
  
    if (instance != null) {
        this.withClusterRole(instance.getClusterRole());
        this.withLiterals(instance.getLiterals());
        this.withClusterRole(instance.getClusterRole());
        this.withLiterals(instance.getLiterals());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ClusterRoleScopeRestriction buildClusterRole() {
    return this.clusterRole!=null ?this.clusterRole.build():null;
  }
  
  public A withClusterRole(ClusterRoleScopeRestriction clusterRole) {
    _visitables.get("clusterRole").remove(this.clusterRole);
    if (clusterRole!=null){ this.clusterRole= new ClusterRoleScopeRestrictionBuilder(clusterRole); _visitables.get("clusterRole").add(this.clusterRole);} else { this.clusterRole = null; _visitables.get("clusterRole").remove(this.clusterRole); } return (A) this;
  }
  
  public boolean hasClusterRole() {
    return this.clusterRole != null;
  }
  
  public ClusterRoleNested<A> withNewClusterRole() {
    return new ClusterRoleNested(null);
  }
  
  public ClusterRoleNested<A> withNewClusterRoleLike(ClusterRoleScopeRestriction item) {
    return new ClusterRoleNested(item);
  }
  
  public ClusterRoleNested<A> editClusterRole() {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(null));
  }
  
  public ClusterRoleNested<A> editOrNewClusterRole() {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(new ClusterRoleScopeRestrictionBuilder().build()));
  }
  
  public ClusterRoleNested<A> editOrNewClusterRoleLike(ClusterRoleScopeRestriction item) {
    return withNewClusterRoleLike(java.util.Optional.ofNullable(buildClusterRole()).orElse(item));
  }
  
  public A addToLiterals(int index,String item) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    this.literals.add(index, item);
    return (A)this;
  }
  
  public A setToLiterals(int index,String item) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    this.literals.set(index, item); return (A)this;
  }
  
  public A addToLiterals(java.lang.String... items) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    for (String item : items) {this.literals.add(item);} return (A)this;
  }
  
  public A addAllToLiterals(Collection<String> items) {
    if (this.literals == null) {this.literals = new ArrayList<String>();}
    for (String item : items) {this.literals.add(item);} return (A)this;
  }
  
  public A removeFromLiterals(java.lang.String... items) {
    if (this.literals == null) return (A)this;
    for (String item : items) { this.literals.remove(item);} return (A)this;
  }
  
  public A removeAllFromLiterals(Collection<String> items) {
    if (this.literals == null) return (A)this;
    for (String item : items) { this.literals.remove(item);} return (A)this;
  }
  
  public List<String> getLiterals() {
    return this.literals;
  }
  
  public String getLiteral(int index) {
    return this.literals.get(index);
  }
  
  public String getFirstLiteral() {
    return this.literals.get(0);
  }
  
  public String getLastLiteral() {
    return this.literals.get(literals.size() - 1);
  }
  
  public String getMatchingLiteral(Predicate<String> predicate) {
    for (String item: literals) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingLiteral(Predicate<String> predicate) {
    for (String item: literals) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withLiterals(List<String> literals) {
    if (literals != null) {this.literals = new ArrayList(); for (String item : literals){this.addToLiterals(item);}} else { this.literals = null;} return (A) this;
  }
  
  public A withLiterals(java.lang.String... literals) {
    if (this.literals != null) {this.literals.clear(); _visitables.remove("literals"); }
    if (literals != null) {for (String item :literals){ this.addToLiterals(item);}} return (A) this;
  }
  
  public boolean hasLiterals() {
    return literals != null && !literals.isEmpty();
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ScopeRestrictionFluent that = (ScopeRestrictionFluent) o;
    if (!java.util.Objects.equals(clusterRole, that.clusterRole)) return false;
  
    if (!java.util.Objects.equals(literals, that.literals)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clusterRole,  literals,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterRole != null) { sb.append("clusterRole:"); sb.append(clusterRole + ","); }
    if (literals != null && !literals.isEmpty()) { sb.append("literals:"); sb.append(literals + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ClusterRoleNested<N> extends ClusterRoleScopeRestrictionFluent<ClusterRoleNested<N>> implements Nested<N>{
    ClusterRoleNested(ClusterRoleScopeRestriction item) {
      this.builder = new ClusterRoleScopeRestrictionBuilder(this, item);
    }
    ClusterRoleScopeRestrictionBuilder builder;
    
    public N and() {
      return (N) ScopeRestrictionFluent.this.withClusterRole(builder.build());
    }
    
    public N endClusterRole() {
      return and();
    }
    
  
  }

}
